
; win32
;;;;;;;;;;;;;;;

;;
;; Exception disposition return values.
;;

ExceptionContinueExecution  equ 0
ExceptionContinueSearch     equ 1
ExceptionNestedException    equ 2
ExceptionCollidedUnwind     equ 3

;;
;; The following values specify the type of failing access when the status is 
;; STATUS_ACCESS_VIOLATION and the first parameter in the execpetion record.
;;

EXCEPTION_READ_FAULT      equ    0 ;; Access violation was caused by a read
EXCEPTION_WRITE_FAULT     equ    1 ;; Access violation was caused by a write
EXCEPTION_EXECUTE_FAULT   equ    8 ;; Access violation was caused by an instruction fetch


;;
;; The following flags control the contents of the CONTEXT structure.
;;


CONTEXT_i386  equ    0x00010000    ;; this assumes that i386 and
CONTEXT_i486  equ    0x00010000    ;; i486 have identical context records

CONTEXT_CONTROL               equ (CONTEXT_i386 | 0x00000001) ;; SS:SP, CS:IP, FLAGS, BP
CONTEXT_INTEGER               equ (CONTEXT_i386 | 0x00000002) ;; AX, BX, CX, DX, SI, DI
CONTEXT_SEGMENTS              equ (CONTEXT_i386 | 0x00000004) ;; DS, ES, FS, GS
CONTEXT_FLOATING_POINT        equ (CONTEXT_i386 | 0x00000008) ;; 387 state
CONTEXT_DEBUG_REGISTERS       equ (CONTEXT_i386 | 0x00000010) ;; DB 0-3,6,7
CONTEXT_EXTENDED_REGISTERS    equ (CONTEXT_i386 | 0x00000020) ;; cpu specific extensions

CONTEXT_FULL equ (CONTEXT_CONTROL | CONTEXT_INTEGER | CONTEXT_SEGMENTS)

CONTEXT_ALL  equ (CONTEXT_CONTROL | CONTEXT_INTEGER | CONTEXT_SEGMENTS |  \
                  CONTEXT_FLOATING_POINT | CONTEXT_DEBUG_REGISTERS | CONTEXT_EXTENDED_REGISTERS)

MAXIMUM_SUPPORTED_EXTENSION equ 0x200

;;
;;  Define the size of the 80387 save area, which is in the context frame.
;;

SIZE_OF_80387_REGISTERS    equ   0x50
SIZE_OF_FLOATING_SAVE_AREA equ ((8*4)+SIZE_OF_80387_REGISTERS)

;;
;; Context Frame
;;
;;  This frame has a several purposes: 1) it is used as an argument to
;;  NtContinue, 2) is is used to constuct a call frame for APC delivery,
;;  and 3) it is used in the user level thread creation routines.
;;
;;  The layout of the record conforms to a standard call frame.
;;

struc CONTEXT

    ;;
    ;; The flags values within this flag control the contents of
    ;; a CONTEXT record.
    ;;
    ;; If the context record is used as an input parameter, then
    ;; for each portion of the context record controlled by a flag
    ;; whose value is set, it is assumed th.th.portion of the
    ;; context record contains valid context. If the context record
    ;; is being used to modify a threads context, then only that
    ;; portion of the threads context will be modified.
    ;;
    ;; If the context record is used as an IN OUT parameter to capture
    ;; the context of a thread, then only those portions of the thread's
    ;; context corresponding to set flags will be returned.
    ;;
    ;; The context record is never used as an OUT only parameter.
    ;;

    .ContextFlags: resd 1

    ;;
    ;; This section is specified/returned if CONTEXT_DEBUG_REGISTERS is
    ;; set in ContextFlags.  Note th.CONTEXT_DEBUG_REGISTERS is NOT
    ;; included in CONTEXT_FULL.
    ;;

    .Dr0: resd 1
    .Dr1: resd 1
    .Dr2: resd 1
    .Dr3: resd 1
    .Dr6: resd 1
    .Dr7: resd 1

    ;;
    ;; This section is specified/returned if the
    ;; ContextFlags word contians the flag CONTEXT_FLOATING_POINT.
    ;;

    .FloatSave: resb SIZE_OF_FLOATING_SAVE_AREA;   (FLOATING_SAVE_AREA)

    ;;
    ;; This section is specified/returned if the
    ;; ContextFlags word contians the flag CONTEXT_SEGMENTS.
    ;;

    .SegGs: resd 1
    .SegFs: resd 1
    .SegEs: resd 1
    .SegDs: resd 1

    ;;
    ;; This section is specified/returned if the
    ;; ContextFlags word contians the flag CONTEXT_INTEGER.
    ;;

    .Edi: resd 1
    .Esi: resd 1
    .Ebx: resd 1
    .Edx: resd 1
    .Ecx: resd 1
    .Eax: resd 1

    ;;
    ;; This section is specified/returned if the
    ;; ContextFlags word contians the flag CONTEXT_CONTROL.
    ;;

    .Ebp: resd 1
    .Eip: resd 1
    .SegCs: resd 1              ;; MUST BE SANITIZED
    .EFlags: resd 1             ;; MUST BE SANITIZED
    .Esp: resd 1
    .SegSs: resd 1

    ;;
    ;; This section is specified/returned if the ContextFlags word
    ;; contains the flag CONTEXT_EXTENDED_REGISTERS.
    ;; The form.and contexts are processor specific
    ;;

    .ExtendedRegisters: resb MAXIMUM_SUPPORTED_EXTENSION

endstruc

struc except_handler
    .ExceptionRecord:   resd 1      ; _EXCEPTION_RECORD
    .EstablisherFrame:  resd 1
    .ContextRecord:     resd 1      ; _CONTEXT
    .DispatcherContext: resd 1
endstruc
SIZEOF_except_handler   equ (4*4)

struc SYSTEM_MODULE_INFORMATION_ENTRY
    .Unknown1:    resd 1
    .Unknown2:    resd 1
    .Base:        resd 1
    .Size:        resd 1
    .Flags:       resd 1
    .Index:       resw 1
    ; Length of module name not including the path, this
    ; field contains valid value only for NTOSKRNL module
    .NameLength:  resw 1
    .LoadCount:   resw 1
    .PathLength:  resw 1
    .ImageName:   resb 256
endstruc
SIZEOF_SYSTEM_MODULE_INFORMATION_ENTRY equ ((5*4)+(4*2)+(256))

struc SYSTEM_MODULE_INFORMATION
    .Count:   resd 1
    .Module:  resb SIZEOF_SYSTEM_MODULE_INFORMATION_ENTRY
endstruc
SIZE_OF_SYSTEM_MODULE_INFORMATION equ (4+SIZEOF_SYSTEM_MODULE_INFORMATION_ENTRY)
